@@ -58,19 +58,19 @@ function header(DocDir) {
   document.write("    installation<\/a><\/dd>");
   document.write("    <dd><a href=\"" + DocDir + "manual\/index.html\" title=\"user manual\">");
   document.write("      manual<\/a><\/dd>");
+  document.write("    <dd><a href=\"" + DocDir + "robodoc.html\" title=\"source code documentation\">");
+  document.write("      code doc<\/a><\/dd>");
   document.write("    <dd><a href=\"" + DocDir + "videos.html\" title=\"instructional videos\">");
       document.write("      videos<\/a><\/dd>");
   document.write("    <dd><a href=\"" + DocDir + "faq.html\" title=\"Frequently Asked Questions\">");
   document.write("      FAQ<\/a><\/dd>");
-  document.write("    <dd><a href=\"http:\/\/groups.google.com\/group\/slippery-chicken\"");
-  document.write("      title=\"user discussion and queries\">");
-  document.write("      forum<\/a><\/dd>");
+//  document.write("    <dd><a href=\"http:\/\/groups.google.com\/group\/slippery-chicken\"");
+//  document.write("      title=\"user discussion and queries\">");
+//  document.write("      forum<\/a><\/dd>");
   document.write("    <dd><a href=\"" + DocDir + "bugs.html\" title=\"how to report a bug\">");
   document.write("      bugs<\/a><\/dd>");
-  document.write("    <dd><a href=\"" + DocDir + "robodoc.html\" title=\"source code documentation\">");
-  document.write("      robodoc<\/a><\/dd>");
-  document.write("    <dd><a href=\"" + DocDir + "search.html\" title=\"search\">");
-  document.write("    search<\/a><\/dd>");
+//  document.write("    <dd><a href=\"" + DocDir + "search.html\" title=\"search\">");
+//  document.write("    search<\/a><\/dd>");
   document.write("    <\/dl>");
   document.write("  <\/li>");
   document.write("<!-- ********************************* -->");
